==> flink-1.12.7-src.tgz: flink-1.12.7/flink-core/src/test/java/org/apache/flink/api/common/typeutils/base/SqlTimeComparatorTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.api.common.typeutils.base;

import org.apache.flink.api.common.typeutils.ComparatorTestBase;
import org.apache.flink.api.common.typeutils.TypeComparator;
import org.apache.flink.api.common.typeutils.TypeSerializer;

import java.sql.Time;

public class SqlTimeComparatorTest extends ComparatorTestBase<Time> {

    @SuppressWarnings("unchecked")
    @Override
    protected TypeComparator<Time> createComparator(boolean ascending) {
        return (TypeComparator) new DateComparator(ascending);
    }

    @Override
    protected TypeSerializer<Time> createSerializer() {
        return new SqlTimeSerializer();
    }

    @Override
    protected Time[] getSortedTestData() {
        return new Time[] {
            Time.valueOf("00:00:00"),
            Time.valueOf("02:42:25"),
            Time.valueOf("14:15:59"),
            Time.valueOf("18:00:45")
        };
    }
}

==> flink-2.1.1-src.tgz: flink-2.1.1/flink-core/src/test/java/org/apache/flink/api/common/typeutils/base/SqlTimeComparatorTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.api.common.typeutils.base;

import org.apache.flink.api.common.typeutils.ComparatorTestBase;
import org.apache.flink.api.common.typeutils.TypeComparator;
import org.apache.flink.api.common.typeutils.TypeSerializer;

import java.sql.Time;

class SqlTimeComparatorTest extends ComparatorTestBase<Time> {

    @SuppressWarnings("unchecked")
    @Override
    protected TypeComparator<Time> createComparator(boolean ascending) {
        return (TypeComparator) new DateComparator(ascending);
    }

    @Override
    protected TypeSerializer<Time> createSerializer() {
        return new SqlTimeSerializer();
    }

    @Override
    protected Time[] getSortedTestData() {
        return new Time[] {
            Time.valueOf("00:00:00"),
            Time.valueOf("02:42:25"),
            Time.valueOf("14:15:59"),
            Time.valueOf("18:00:45")
        };
    }
}
